summaryrefslogtreecommitdiffstats
path: root/content/browser/tab_contents/navigation_details.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/browser/tab_contents/navigation_details.h')
-rw-r--r--content/browser/tab_contents/navigation_details.h19
1 files changed, 5 insertions, 14 deletions
diff --git a/content/browser/tab_contents/navigation_details.h b/content/browser/tab_contents/navigation_details.h
index 11448c9..2bb3df3 100644
--- a/content/browser/tab_contents/navigation_details.h
+++ b/content/browser/tab_contents/navigation_details.h
@@ -37,16 +37,8 @@ struct LoadCommittedDetails {
// The previous URL that the user was on. This may be empty if none.
GURL previous_url;
- // True when this load was non-user initated. This corresponds to a
- // a NavigationGestureAuto call from WebKit (see webview_delegate.h).
- // We also count reloads and meta-refreshes as "auto" to account for the
- // fact that WebKit doesn't always set the user gesture properly in these
- // cases (see bug 1051891).
- bool is_auto;
-
// True if the committed entry has replaced the exisiting one.
// A non-user initiated redirect causes such replacement.
- // This is somewhat similiar to is_auto, but not exactly the same.
bool did_replace_entry;
// True if the navigation was in-page. This means that the active entry's
@@ -63,12 +55,11 @@ struct LoadCommittedDetails {
// Use SSLManager::DeserializeSecurityInfo to decode it.
std::string serialized_security_info;
- // Returns whether the user probably felt like they navigated somewhere new.
- // We often need this logic for showing or hiding something, and this
- // returns true only for main frame loads that the user initiated, that go
- // to a new page.
- bool is_user_initiated_main_frame_load() const {
- return !is_auto && !is_in_page && is_main_frame;
+ // Returns whether the main frame navigated to a different page (e.g., not
+ // scrolling to a fragment inside the current page). We often need this logic
+ // for showing or hiding something.
+ bool is_navigation_to_different_page() const {
+ return is_main_frame && !is_in_page;
}
// The HTTP status code for this entry..